@@ -1,5 +1,4 @@
-ModelMats <-
-function (time, ii, timeL = NULL) {
+ModelMats <- function (time, ii, timeL = NULL) {
     GQsurv <- if (object$control$GQsurv == "GaussKronrod") gaussKronrod() else gaussLegendre(object$control$GQsurv.k)
     wk <- GQsurv$wk
     sk <- GQsurv$sk
@@ -11,7 +10,11 @@ function (time, ii, timeL = NULL) {
         P <- time / 2
         st <- P * (sk + 1)
     }
-    data.id2 <- data.id[id.GK, ]
+    #data.id2 <- data.id[id.GK, ]
+    data.id2 <- newdata[id == ii, ]
+    ind <- findInterval(st, obs.times[[ii]])
+    ind[ind < 1] <- 1
+    data.id2 <- data.id2[ind, , drop = FALSE]
     data.id2[[timeVar]] <- pmax(st - lag, 0)
     kn <- object$control$knots
     W2s <- splineDesign(unlist(kn, use.names = FALSE), st, 
