@@ -13,14 +13,14 @@ function (x, df = NULL, knots = NULL, intercept = FALSE, Boundary.knots = range(
     GK <- gaussKronrod(15)
     wk <- GK$wk
     sk <- GK$sk
-    P1 <- (x + from) / 2
-    P2 <- (x - from) / 2
+    P1 <- c(x + from) / 2
+    P2 <- c(x - from) / 2
     st <- outer(P2, sk) + P1
     out <- vector("list", 15L)
     for (i in seq_len(15)) {
         out[[i]] <- wk[i] * bs(st[, i], knots = kn, Boundary.knots = Bkn, intercept = intercept)
         if (!is.null(weight.fun)) {
-            ww <- weight.fun(st[, i], x, ...)
+            ww <- c(weight.fun(st[, i], x, ...))
             out[[i]] <- out[[i]] * ifelse(is.finite(ww), ww, 0)
         }
             
